==> nextcloud-app-contacts-4.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/mn.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Дэлгэрэнгүй",
    "All contacts" : "Бүх харилцагчид",
    "Contacts" : "Харилцагчид",
    "Copy to full name" : "Бүтэн нэр хуулах",
    "Loading …" : "Уншиж байна...",
    "Add member" : "Гишүүн нэмэх",
    "Download" : "Татаж авах",
    "Groups" : "Багууд",
    "Group name" : "Бүлгийн нэр",
    "Rename" : "Нэр солих",
    "Enabled" : "Идэвхижүүлэх",
    "Delete" : "Устгах",
    "Copied" : "Хуулагдсан",
    "Cannot copy" : "Хуулагдаагүй",
    "Copy link" : "Холбоос хуулах",
    "Share with users or groups" : "Бусдад түгээх",
    "can edit" : "засаж чадна",
    "First name" : "Нэр",
    "Last name" : "Овог",
    "Display name" : "Харагдах нэр",
    "Last modified" : "Сүүлд өөрчилсөн",
    "Description" : "Тайлбар",
    "Upload a new picture" : "Шинэ зураг оруулах",
    "Choose from Files" : "Файлаас сонгох",
    "Download picture" : "Зураг татаж авах",
    "Delete picture" : "Зураг устгах",
    "Invalid image" : "буруу зураг",
    "Image is too big (max 1MB)." : "Зургийн хэмжээ их /max 1MB/",
    "Name" : "Нэр",
    "Title" : "Цол/Албан тушаал",
    "Select address book" : "Хаягийн бүртгэл сонгох",
    "Cancel" : "болиулах",
    "Address book" : "Хаягийн бүртгэл",
    "New contact" : "Шинэ харилцагч",
    "No results" : "Үр дүн байхгүй",
    "Close" : "Хаах",
    "Import" : "Импорт",
    "Not grouped" : "Багт ороогүй",
    "User" : "Хэрэглэгч",
    "Email" : "Цахим шуудан",
    "Nickname" : "Товч нэр",
    "Detailed name" : "Дэлгэрэнгүй нэр",
    "Additional names" : "Нэмэлт нэрүүд",
    "Notes" : "Тэмдэглэл",
    "Website" : "Цахим хуудас",
    "Location" : "Байршил",
    "Home" : "Гэр",
    "Work" : "Ажил",
    "Other" : "Бусад",
    "Address" : "Хаяг",
    "Post office box" : "Шуудангийн хайрцаг",
    "City" : "Хот",
    "State or province" : "Аймаг",
    "Postal code" : "Шуудангийн код",
    "Country" : "Улс",
    "Birthday" : "Төрсөн өдөр",
    "Date of death" : "Нас барсан огноо",
    "Phone" : "Утас",
    "Mobile" : "Гар утас",
    "Fax" : "Факс",
    "Fax home" : "Гэрийн факс",
    "Fax work" : "Ажлын факс",
    "Social network" : "Олон нийтийн сүлжээ",
    "Child" : "хүүхэд",
    "Mother" : "эх",
    "Father" : "эцэг",
    "Parent" : "эцэг эх",
    "Brother" : "ах",
    "Sister" : "эгч",
    "Relative" : "Хамаарал",
    "Friend" : "Найз",
    "Manager" : "Менежер",
    "Co-worker" : "Хамтран ажиллагч",
    "Gender" : "Хүйс",
    "Female" : "Эмэгтэй",
    "Male" : "Эрэгтэй",
    "None" : "юу ч үгүй",
    "Unknown" : "Үл танигдах зүйл",
    "Time zone" : "Цагийн бүс"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-4.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/mn.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Дэлгэрэнгүй",
    "All contacts" : "Бүх харилцагчид",
    "Contacts" : "Харилцагчид",
    "Copy to full name" : "Бүтэн нэр хуулах",
    "Loading …" : "Уншиж байна...",
    "Add member" : "Гишүүн нэмэх",
    "Delete circle" : "бүлгийг устгах",
    "Download" : "Татаж авах",
    "Groups" : "Багууд",
    "Group name" : "Бүлгийн нэр",
    "Circles" : "Тойрог",
    "Create a new circle" : "шинэ бүлэг үүсгэх",
    "Rename" : "Нэр солих",
    "Enabled" : "Идэвхижүүлэх",
    "Delete" : "Устгах",
    "Copied" : "Хуулагдсан",
    "Cannot copy" : "Хуулагдаагүй",
    "Copy link" : "Холбоос хуулах",
    "Share with users or groups" : "Бусдад түгээх",
    "can edit" : "засаж чадна",
    "First name" : "Нэр",
    "Last name" : "Овог",
    "Display name" : "Харагдах нэр",
    "Last modified" : "Сүүлд өөрчилсөн",
    "Password protection" : "Password protection",
    "Save" : "Хадгалах",
    "Description" : "Тайлбар",
    "Upload a new picture" : "Шинэ зураг оруулах",
    "Choose from Files" : "Файлаас сонгох",
    "Download picture" : "Зураг татаж авах",
    "Delete picture" : "Зураг устгах",
    "Invalid image" : "буруу зураг",
    "Image is too big (max 1MB)." : "Зургийн хэмжээ их /max 1MB/",
    "Name" : "Нэр",
    "Title" : "Цол/Албан тушаал",
    "Select address book" : "Хаягийн бүртгэл сонгох",
    "Cancel" : "болиулах",
    "Address book" : "Хаягийн бүртгэл",
    "New contact" : "Шинэ харилцагч",
    "No results" : "Үр дүн байхгүй",
    "Personal circle" : "Хувийн тойрог",
    "Pending" : "Хүлээгдэж байгаа",
    "Close" : "Хаах",
    "Import" : "Импорт",
    "Not grouped" : "Багт ороогүй",
    "Circle" : "Тойрог",
    "User" : "Хэрэглэгч",
    "Group" : "Бүлэг",
    "Email" : "Цахим шуудан",
    "Member" : "Гишүүн",
    "Moderator" : "Шалгагч",
    "Admin" : "Админ",
    "Owner" : "Эзэмшигч",
    "Users" : "хэрэглэгч",
    "Nickname" : "Товч нэр",
    "Detailed name" : "Дэлгэрэнгүй нэр",
    "Additional names" : "Нэмэлт нэрүүд",
    "Notes" : "Тэмдэглэл",
    "Website" : "Цахим хуудас",
    "Location" : "Байршил",
    "Home" : "Гэр",
    "Work" : "Ажил",
    "Other" : "Бусад",
    "Address" : "Хаяг",
    "Post office box" : "Шуудангийн хайрцаг",
    "City" : "Хот",
    "State or province" : "Аймаг",
    "Postal code" : "Шуудангийн код",
    "Country" : "Улс",
    "Birthday" : "Төрсөн өдөр",
    "Date of death" : "Нас барсан огноо",
    "Phone" : "Утас",
    "Mobile" : "Гар утас",
    "Fax" : "Факс",
    "Fax home" : "Гэрийн факс",
    "Fax work" : "Ажлын факс",
    "Social network" : "Олон нийтийн сүлжээ",
    "Child" : "хүүхэд",
    "Mother" : "эх",
    "Father" : "эцэг",
    "Parent" : "эцэг эх",
    "Brother" : "ах",
    "Sister" : "эгч",
    "Relative" : "Хамаарал",
    "Friend" : "Найз",
    "Manager" : "Менежер",
    "Co-worker" : "Хамтран ажиллагч",
    "Gender" : "Хүйс",
    "Female" : "Эмэгтэй",
    "Male" : "Эрэгтэй",
    "None" : "юу ч үгүй",
    "Unknown" : "Үл танигдах зүйл",
    "Time zone" : "Цагийн бүс"
},
"nplurals=2; plural=(n != 1);");
